base_menu
library
Classes
-
BaseControl<T extends Object?>
-
An interactive widget that manages common UI states and coordinates pointer
and keyboard activation.
-
BaseFocusable<T extends Object?>
-
A widget that manages focus state for type
T and propagates it
to descendants in the widget tree.
-
BaseHoverable<T extends Object?>
-
A widget that manages hover state for type
T and propagates it
to descendants in the widget tree.
-
A widget that anchors a popup menu to a child widget and manages its
visibility.
-
A widget that groups BaseMenus into an accessible menu bar.
-
A widget that manages the state of a menu item and propagates it to
descendants in the widget tree.
-
A widget that displays menu items in a linear layout along a given
orientation.
-
An InheritedWidget that provides the orientation and isSubmenu status
of a menu to its descendants.
-
A widget that displays a hierarchical submenu when opened.
-
A delegate whose build method builds a widget that positions the menu
panel of a BaseMenu.
-
EdgeBehavior
-
Describes how a BaseMenu.menu should be positioned when it overflows the
edge of the screen.
-
EdgeBehaviorStrategy
-
Defines the positioning behavior of a BaseMenu when it overflows the edge
of the screen.
-
An Intent that signals the nearest ancestor BaseMenu should be opened
and focused.
-
An intent that moves focus to the next item within a horizontal BaseMenu or BaseMenuBar.
-
An intent that moves focus to the previous item within a horizontal BaseMenu or BaseMenuBar.
-
A geometry object that holds the anchor and target rectangles for menu
aim assist.
-
A widget that intercepts pointer hit-tests when the pointer moves
diagonally from a menu item toward a submenu.
-
An inherited widget used to configure menu aim assist behavior for all
BaseMenu and BaseSubmenu descendants in the widget tree.
-
A delegate that builds a widget that positions the menu panel of a BaseMenu.
-
An intent that moves focus to the next item in a vertical BaseMenu or BaseMenuBar.
-
An intent that moves focus to the previous item in a vertical BaseMenu or BaseMenuBar.
Typedefs
-
Signature for a callback that builds a widget that surrounds the overlay of
a BaseMenu.