menu property
A widget containing the contents of the menu. This widget will only be displayed when the menu is open.
Typically, this is a BaseMenuPanel that displays a list of menu items, but it can be any widget.
Implementation
@override
final Widget menu;